@@ -61,19 +61,17 @@ class AndroidChroot(DeviceModule):
         """In SHR on Neo, we need to temporary disable fullscreen
         (if we are in fullscreen),
         or else the text entry box won't show up"""
-        display = self.m.get('display', None)
-        if display:
-            if display.getFullscreenEnabled():
-                display.fullscreenToggle()
+        if self.modrana.gui:
+            if self.modrana.gui.fullscreen:
+                self.modrana.gui.toggleFullscreen()
                 self.tempUnfullscreen = True
 
     def textEntryDone(self):
         """Restore fullscreen if needed"""
         if self.tempUnfullscreen:
-            display = self.m.get('display', None)
-            if display:
-                if not display.getFullscreenEnabled():
-                    display.fullscreenToggle()
+            if self.modrana.gui:
+                if not self.modrana.gui.fullscreen:
+                    self.modrana.gui.toggleFullscreen()
                     self.tempUnfullscreen = False
 
     def needsQuitButton(self):
