@@ -20,6 +20,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
+import logging
+
 from core import constants
 
 from modules.base_module import RanaModule
@@ -49,6 +51,17 @@ class GUIModule(RanaModule):
         """
         self.subtypeId = subtypeId
 
+    def handleMessage(self, message, messageType, args):
+        if message == "fullscreen" and messageType == "ms":
+            if args == "toggle":
+                self.toggleFullscreen()
+            elif args == "enable":
+                self.setFullscreen(True)
+            elif args == "disable":
+                self.setFullscreen(False)
+            else:
+                self.log.error("incorrect fullscreen message argument: %s", args)
+
     def resize(self, mrw, h):
         """resize the GUI to given width and height"""
         pass
@@ -194,6 +207,13 @@ class GUIModule(RanaModule):
         else:
             return False
 
+    def _getLog(self):
+        guiModuleSuffix = ".".join(self._importName.split("_", 1))
+        # this should turn "gui_gtk" to gui.gtk,
+        # which together with the "mod" prefix should
+        # result in a nice "mod.gui.gtk" logger hierarchy
+        return logging.getLogger("mod.%s" % guiModuleSuffix)
+
     def _getStyleConstants(self):
         # as True == 1 and False == 0,
         # we use the highDPI boolean as a tuple index
@@ -290,12 +310,27 @@ class GUIModule(RanaModule):
             w, h = screenWH
         return w == h
 
+    def shouldStartInFullscreen(self):
+        """Report if the GUI should start in fullscreen
+        * could be required by device module
+        * could be requested by CLI flag
+        * could be enabled in options
 
+        :returns: if GUI should start in fullscreen or not
+        :rtype: bool
+        """
+        return any(
+            (self.modrana.dmod.startInFullscreen(),
+               self.modrana.args.fullscreen,
+               self.get("startInFullscreen", False))
+        )
 
+    def showQuitButton(self):
+        """Report if the GUI should show a quit button
+        * could be required by device module
+        * could be enabled in options
 
-
-
-
-
-
-
+        :returns: if GUI should show quit button or not
+        :rtype: bool
+        """
+        return any((self.dmod.needsQuitButton(), self.get("showQuitButton", False)))
\ No newline at end of file
