@@ -37,7 +37,6 @@ class Display(RanaModule):
     def __init__(self, m, d, i):
         RanaModule.__init__(self, m, d, i)
 
-        self.fullscreen = False
         """according to documentation on:
         (http://wiki.maemo.org/PyMaemo/Python-osso_examples#Device_State),
         every display_blanking_pause() call pauses screenblank for 60 seconds,
@@ -61,7 +60,7 @@ class Display(RanaModule):
             # the QML context
             pass
         else:
-            print("display: WARNING, unhandled GUI toolkit, redraw disable if not visible might not work")
+            self.log.warning("WARNING, unhandled GUI toolkit, redraw disable if not visible might not work")
 
         # check the screen blanking mode on startup
         self.checkScreenBlankingMode()
@@ -69,15 +68,11 @@ class Display(RanaModule):
         cron = self.m.get('cron', None)
         if cron:
             # run the callback directly for the first time
-            self._updateDisplayControlCB
             cron.addTimeout(self._updateDisplayControlCB, self.msScreenBlankPauseIntervalMs, self,
                             "screen blanking update")
 
     def handleMessage(self, message, messageType, args):
-        if message == "fullscreen" and messageType == "ms":
-            if args == "toggle":
-                self.fullscreenToggle()
-        elif message == "blankingModeChanged":
+        if message == "blankingModeChanged":
             self.checkScreenBlankingMode() # check if screen blanking changed
         elif message == "checkShowRedrawTime":
             state = self.get('showRedrawTime', False)
@@ -88,13 +83,13 @@ class Display(RanaModule):
     def enableRedraw(self, reason="not given"):
         """enable window redrawing"""
         self.modrana.gui.setRedraw(True)
-        print("display: redraw ON (%s)" % reason)
+        self.log.info("redraw ON (%s)" % reason)
         self.set('needRedraw', True) # make sure the screen is refreshed
 
     def disableRedraw(self, reason="not given"):
         """disable window redrawing"""
         self.modrana.gui.setRedraw(False)
-        print("display: redraw OFF (%s)" % reason)
+        self.log.info("redraw OFF (%s)" % reason)
 
     def windowStateChangedCallback(self, window, event):
         if event.new_window_state == gtk.gdk.WINDOW_STATE_ICONIFIED:
@@ -110,30 +105,6 @@ class Display(RanaModule):
         else:
             self.enableRedraw(reason="window is un-obscured or partially obscured")
 
-    def fullscreenToggle(self):
-        """toggle fullscreen state"""
-        if self.fullscreen:
-            self.modrana.gui.setFullscreen(False)
-            self.fullscreen = False
-            self.menusSetFullscreen(self.fullscreen)
-            print("going out of fullscreen")
-        else:
-            self.modrana.gui.setFullscreen(True)
-            self.fullscreen = True
-            self.menusSetFullscreen(self.fullscreen)
-            print("going to fullscreen")
-
-    def menusSetFullscreen(self, value):
-        """update the cached value in the menus module"""
-        m = self.m.get('menu', None)
-        if m:
-            m.fullscreen = value
-
-    def getFullscreenEnabled(self):
-        """
-        True - we are in fullscreen, False otherwise
-        """
-        return self.fullscreen
 
     # * screen blanking control *
 
@@ -162,31 +133,31 @@ class Display(RanaModule):
             if mode == 'always':
                 self.checkConditionsStop()
                 self.screenBlankingControlStart()
-                print("display: keep display ON -> always")
+                self.log.info("keep display ON -> always")
             elif mode == 'never':
                 self.checkConditionsStop()
                 self.screenBlankingControlStop()
-                print("display: keep display ON -> never :)")
+                self.log.info("keep display ON -> never :)")
             elif mode == 'moving':
                 self.screenBlankingControlStop()
                 self.checkConditionsStart(self.checkMovement)
-                print("display: keep display ON -> while moving")
+                self.log.info("keep display ON -> while moving")
             elif mode == 'movingInFullscreen':
                 self.screenBlankingControlStop()
                 self.checkConditionsStart(self.checkFullscreenMovement)
-                print("display: keep display ON -> while moving in Fullscreen")
+                self.log.info("keep display ON -> while moving in Fullscreen")
             elif mode == 'fullscreen':
                 self.screenBlankingControlStop()
                 self.checkConditionsStart(self.checkFullscreen)
-                print("display: keep display ON -> while in Fullscreen")
+                self.log.info("keep display ON -> while in Fullscreen")
             elif mode == 'gpsFix':
                 self.screenBlankingControlStop()
                 self.checkConditionsStart(self.checkGPSFix)
-                print("display: keep display ON -> while there is a GPS fix")
+                self.log.info("keep display ON -> while there is a GPS fix")
             elif mode == 'centred':
                 self.screenBlankingControlStop()
                 self.checkConditionsStart(self.checkCentred)
-                print("display: keep display ON -> while there is a GPS fix")
+                self.log.info("keep display ON -> while there is a GPS fix")
 
     def screenBlankingControlStart(self):
         self.pauseScreenBlanking()
@@ -207,7 +178,7 @@ class Display(RanaModule):
 
     def checkFullscreenMovement(self):
         """check if we are in fullscreen and moving"""
-        if self.fullscreen:
+        if self.modrana.gui.fullscreen:
             # OK, we are in fullscreen, check movement
             self.checkMovement()
         else:
@@ -217,7 +188,7 @@ class Display(RanaModule):
 
     def checkFullscreen(self):
         """check if we are in fullscreen"""
-        if self.fullscreen:
+        if self.modrana.gui.fullscreen:
             # OK, we are in fullscreen, check if blanking is being paused
             if self.pauseScreenBlankingEnabled == False:
                 # unlock screen
