@@ -99,14 +99,14 @@ class Options(RanaModule):
         if groupID in self.options:
             self.options[groupID][0] = "set:menu:options#%s" % parentID
         else:
-            print('options - set group parent: group not found: %s' % groupID)
+            self.log.error("can't set group parent - group %s not found", groupID)
 
     def getGroupParent(self, groupID):
         """set the parent id of a given group id"""
         if groupID in self.options:
             return self.options[groupID][0]
         else:
-            print('options - get group parent: group not found: %s' % groupID)
+            self.log.error("can't get group parent - group %s not found", groupID)
 
     def clearGroup(self, groupID):
         """clear a given group from any options,
@@ -328,7 +328,7 @@ class Options(RanaModule):
             self.options[group][2].append(newOption)
             self.keyDefault[variable] = default
         else:
-            print("options: group %s does not exist, call addGroup to create it first" % group)
+            self.log.error("group %s does not exist, call addGroup to create it first", group)
 
     def addRawOption(self, optionData):
         """add a raw option to options
@@ -346,36 +346,36 @@ class Options(RanaModule):
             items = choices['items']
             self.addItemsOption(title, variable, items, group, default, fakeMode=fakeMode)
         else: # no side effects, just add the raw option
-            if self.options.has_key(group):
+            if group in self.options:
                 self.options[group][2].append(optionData)
                 self.keyDefault[variable] = default
             else:
-                print("options: group %s does not exist, can't add a raw option to it" % group)
+                self.log.error("group %s does not exist, can't add a raw option to it", group)
 
     def removeOption(self, categoryId, groupId, variable):
         """remove an option given by group and variable name"""
 
         group = self._getGroupId(categoryId, groupId)
 
-        if self.options.has_key(group):
+        if group in self.options:
             remove = lambda x: x[1] == variable
             self.options[group][2][:] = [x for x in self.options[group][2] if not remove(x)]
             if variable in self.keyDefault:
                 del self.keyDefault[variable]
         else:
-            print("options: group %s does not exist, so option with variable %s can not be removed" % (group, variable))
+            self.log.error("group %s does not exist, so option with variable %s can not be removed", group, variable)
 
     def getOption(self, groupID, index):
         """get a options item from a given group by its index"""
-        if self.options.has_key(groupID):
+        if groupID in self.options:
             try:
                 return self.options[groupID][2][index]
             except IndexError:
-                print("options: group %s has no index %d, so this option can not be returned" % (groupID, index))
+                self.log.error("group %s has no index %d, so this option can not be returned", groupID, index)
                 return False
 
         else:
-            print("options: group %s does not exist, so option with index %d can not be returned" % (groupID, index))
+            self.log.error("group %s does not exist, so option with index %d can not be returned", groupID, index)
             return False
 
     def getKeyDefault(self, key, default=None):
@@ -403,6 +403,9 @@ class Options(RanaModule):
         addBoolOpt = self.addBoolOption
         addItems = self.addItemsOption
 
+        # useful notifications
+        notifyRestartNeeded = "ml:notification:m:restart modRana to apply this change;3"
+
         # * the Map category *
         catMap = addCat("Map", "map", "map")
 
@@ -562,6 +565,15 @@ class Options(RanaModule):
                group,
                'files')
         addBoolOpt("Store downloaded tiles", "storeDownloadedTiles", group, True)
+        addOpt("Sqlite tile db commit interval", "sqliteTileDatabaseCommitInterval",
+               [(1, "1 second", notifyRestartNeeded),
+                (2, "2 seconds", notifyRestartNeeded),
+                (5, "5 seconds (default)", notifyRestartNeeded),
+                (10, "10 seconds", notifyRestartNeeded),
+                (30, "30 seconds", notifyRestartNeeded),
+                (60, "1 minute", notifyRestartNeeded)],
+               group,
+               150)
 
         # * the view category *
         catView = addCat("View", "view", "view")
@@ -586,6 +598,16 @@ class Options(RanaModule):
                group,
                "auto")
 
+        # if non-fullscreen mode is supported on the device, add a button
+        # that enables starting in fullscreen
+        # (requested by N900 users)
+        if not self.modrana.dmod.fullscreenOnly():
+            addBoolOpt("Start in fullscreen", "startInFullscreen", group, False)
+
+        # if the quit button should be shown even if it is not needed on the
+        # given platform
+        if not self.modrana.gui.showQuitButton():
+            addBoolOpt("Show Quit button", "showQuitButton", group, False)
 
         # ** screen
         # only add if supported on device
@@ -617,9 +639,10 @@ class Options(RanaModule):
                 currentTheme = self.get('currentTheme', None)
                 if currentTheme is not None:
                     if currentTheme not in themeList:
-                        print("options: theme with id %s is not available,\n"
-                              "switching back to default theme" % currentTheme)
-                        self.set('currentTheme', defaultTheme) # theme not valid, reset to default
+                        self.log.error("theme with id %s is not available,\nswitching "
+                                       "back to default theme", currentTheme)
+                        # theme not valid, reset to default
+                        self.set('currentTheme', defaultTheme)
 
                 themeChangedMessage = "icons:themeChanged"
                 nameValueList = map(lambda x: (x, x, themeChangedMessage), themeList)
@@ -950,13 +973,24 @@ class Options(RanaModule):
                group,
                "full")
 
-        addOpt("Max nr. of threads for tile auto-download", "maxAutoDownloadThreads2",
-               [(5, "5"),
-                (10, "10 (default)"),
-                (20, "20"),
-                (30, "30"),
-                (40, "40"),
-                (50, "50")],
+        addOpt("Auto tile download thread count", "maxAutoDownloadThreads2",
+               [(1, "1 (serial)", notifyRestartNeeded),
+                (5, "5", notifyRestartNeeded),
+                (10, "10 (default)", notifyRestartNeeded),
+                (20, "20", notifyRestartNeeded),
+                (30, "30", notifyRestartNeeded),
+                (40, "40", notifyRestartNeeded),
+                (50, "50", notifyRestartNeeded)],
+               group,
+               10)
+
+        addOpt("Batch tile download thread count", "maxDlThreads",
+               [(1, "1 (serial)"),
+                (2, "2"),
+                (3, "3"),
+                (5, "5 (default)"),
+                (10, "10"),
+                (20, "20")],
                group,
                10)
 
@@ -1051,6 +1085,28 @@ class Options(RanaModule):
         addBoolOpt("Print tile cache status to terminal", "reportTileCacheStatus", group, False)
         addBoolOpt("Tile loading status to terminal", "tileLoadingDebug", group, False)
         addBoolOpt("Redraw screen once a new tile is loaded", "tileLoadedRedraw", group, True)
+        addOpt("In memory tile cache size", "memoryTileCacheSize",
+               [(20, "20", notifyRestartNeeded),
+                (50, "50", notifyRestartNeeded),
+                (100, "100", notifyRestartNeeded),
+                (150, "150 (default)", notifyRestartNeeded),
+                (200, "200", notifyRestartNeeded),
+                (300, "300", notifyRestartNeeded),
+                (500, "500", notifyRestartNeeded),
+                (1000, "1000", notifyRestartNeeded)],
+               group,
+               150)
+        addOpt("Auto tile download queue size", "autoDownloadQueueSize",
+               [(1, "1", notifyRestartNeeded),
+                (10, "10", notifyRestartNeeded),
+                (20, "20", notifyRestartNeeded),
+                (50, "50", notifyRestartNeeded),
+                (100, "100 (default)", notifyRestartNeeded),
+                (200, "200", notifyRestartNeeded),
+                (500, "500", notifyRestartNeeded),
+                (1000, "1000", notifyRestartNeeded)],
+               group,
+               100)
         addBoolOpt("Remove dups before batch dl", "checkTiles", group, False)
         # ** tracklog drawing
         group = addGroup("Tracklogs", "tracklogs", catDebug, "generic")
@@ -1093,12 +1149,7 @@ class Options(RanaModule):
         try:
             return dict((k, v) for k, v in six.iteritems(inputDict) if k[0] != '#')
         except Exception:
-            import sys
-
-            e = sys.exc_info()[1]
-            print(
-                'options: error while filtering options\nsome nonpersistent keys might have been left in\nNOTE: keys should be strings of length>=1\n'
-                , e)
+            self.log.exception("error while filtering options\nsome nonpersistent keys might have been left in\nNOTE: keys should be strings of length>=1")
             return self.d
 
     def _reloadKeyStateList(self, groupID, index, key):
@@ -1210,12 +1261,12 @@ class Options(RanaModule):
                 if target == 'packListMonav':
                     self._reloadMonavPackList()
             else:
-                print('options: error - update target not specified')
+                self.log.error('update target not specified')
 
     def _reloadMonavPackList(self):
         route = self.m.get('route', None)
         if route:
-            print('options: reloading Monav data pack list')
+            self.log.info('reloading Monav data pack list')
             # wee need a list of (name, key) tuples
             self.monavPackList = map(lambda x: (x, x), route.getAvailableMonavDataPacks())
 
@@ -1243,7 +1294,7 @@ class Options(RanaModule):
     def handleTextEntryResult(self, key, result):
         (optionType, variable) = key.split("_", 1)
         if optionType == "editVariable":
-            print("editing variable: %s with: %s" % (variable, result))
+            self.log.info("editing variable: %s with: %s", variable, result)
             self.set(variable, result)
 
     def drawMenu(self, cr, menuName, args=None):
