@@ -111,7 +111,7 @@ class RouteProfile(RanaModule):
 
         units = self.m.get('units', None)
         if units is None:
-            print("routeProfile, lineChart: Units module missing")
+            self.log.error("lineChart: Units module missing")
             return
 
         length = int(len(elevList))
@@ -146,9 +146,9 @@ class RouteProfile(RanaModule):
             cuMinimum = units.m2CurrentUnitString(minimum, 3, short=True)
             cuMaximum = units.m2CurrentUnitString(maximum, 3, short=True)
             middle = minimum + (maximum - minimum) / 2.0
-            #      print(minimum)
-            #      print(middle)
-            #      print(maximum)
+            #      self.log.debug(minimum)
+            #      self.log.debug(middle)
+            #      self.log.debug(maximum)
             cuMiddle = units.m2CurrentUnitString(middle, 3, short=True)
             yTicks = [{'label': cuMinimum, 'v': minimum - 15},
                       {'label': cuMiddle, 'v': middle + 15 / 2.0},
