@@ -93,15 +93,15 @@ class Tracklog(RanaModule):
 
     def handleMessage(self, message, messageType, args):
         if message == "startLogging":
-            print("tracklog: starting to log")
+            self.log.info("starting to log")
             # start a new log
             if not self.loggingEnabled:
                 self.loggingEnabled = True
-                print("tracklog: initializing the log file")
+                self.log.info("initializing the log file")
                 self.initLog()
             # or resume an existing one
             elif self.loggingEnabled == True & self.loggingPaused == True:
-                print("tracklog: resuming the logging")
+                self.log.info("resuming the logging")
                 self.loggingPaused = False
             self.set('needRedraw', True)
 
@@ -110,14 +110,14 @@ class Tracklog(RanaModule):
             self.set('needRedraw', True)
 
         elif message == "stopLogging":
-            print("tracklog: stopping logging")
+            self.log.info("stopping logging")
             self.stopLogging()
             self.set('needRedraw', True)
 
         elif message == 'nameInput':
             entry = self.m.get('textEntry', None)
             if entry is None:
-                print("tracklog: error, text entry module is not loaded")
+                self.log.error("error, text entry module is not loaded")
                 return
             entryText = ""
             logNameEntry = self.get('logNameEntry', None)
@@ -194,25 +194,25 @@ class Tracklog(RanaModule):
 
         self.lastUpdateTimestamp = time.time()
         self.lastCoords = self.get('pos', None)
-        print("tracklog: log file initialized")
+        self.log.info("log file initialized")
 
     def pauseLogging(self):
         """pause logging"""
         if self.loggingEnabled:
             self._saveLogIncrement() # save increment
             self.loggingPaused = True # pause logging
-            print('tracklog: logging paused')
+            self.log.info('logging paused')
         else:
-            print("tracklog: can't pause logging - no logging in progress")
+            self.log.error("can't pause logging - no logging in progress")
 
     def unPauseLogging(self):
         """pause logging"""
         if self.loggingEnabled:
             self._saveLogIncrement() # save increment
             self.loggingPaused = False # un-pause logging
-            print('tracklog: logging un-paused')
+            self.log.info('logging un-paused')
         else:
-            print("tracklog: can't un-pause logging - no logging in progress")
+            self.log.error("can't un-pause logging - no logging in progress")
 
     def _updateLogCB(self):
         """add current position at the end of the log"""
@@ -253,10 +253,8 @@ class Tracklog(RanaModule):
                     try:
                         addToTrace = geo.distanceApprox(lat, lon, lat1, lon1) * 1000 >= DONT_ADD_TO_TRACE_THRESHOLD
                     except Exception:
-                        import sys
-                        e = sys.exc_info()[1]
-                        print("tracklog: measuring distance failed (yeah, really! :P), adding point anyway")
-                        print(e)
+                        self.log.exception("measuring distance failed (yeah, really! :P), adding point anyway")
+
                     if addToTrace:
                         self._addLL2Trace(lat, lon)
                 else: # this is the first known log point, just add it
@@ -279,24 +277,19 @@ class Tracklog(RanaModule):
         (only the increment from last save needs to be stored)"""
         if not self.loggingPaused:
             self._saveLogIncrement()
-            print('tracklog: temporary log files saved')
+            self.log.info('temporary log files saved')
 
     def _saveLogIncrement(self):
         """save current log increment to storage"""
         try:
             self.log1.flush()
         except Exception:
-            import sys
-            e = sys.exc_info()[1]
-            print('tracklog: saving primary temporary log failed')
-            print(e)
+            self.log.exception('saving primary temporary log failed')
+
         try:
             self.log2.flush()
         except Exception:
-            import sys
-            e = sys.exc_info()[1]
-            print('tracklog: saving secondary temporary log failed')
-            print(e)
+            self.log.exception('saving secondary temporary log failed')
 
     def generateLogName(self):
         """generate a unique name for a log"""
@@ -326,8 +319,8 @@ class Tracklog(RanaModule):
             self.saveLogTimerId = cron.addTimeout(self._saveLogCB, saveTimeout, self, "save tracklog increment")
 
             # report the timer cadence
-            print("tracklog: starting track logging timers: update every %d s, save every %d s" %
-                  (updateTimeout/1000, saveTimeout/1000))
+            self.log.info("starting track logging timers: update every %d s, save every %d s",
+                          updateTimeout/1000, saveTimeout/1000)
             # update timer intervals if they are changed
             # in the persistent dictionary
             self.modrana.watch('tracklogLogInterval', self._updateIntervalChangedCB)
@@ -339,9 +332,9 @@ class Tracklog(RanaModule):
             interval = int(newInterval) * 1000
             if cron:
                 cron.modifyTimeout(self.updateLogTimerId, interval)
-                print('tracklog: tracklog update interval changed to %s s' % newInterval)
+                self.log.info('tracklog update interval changed to %s s', newInterval)
             else:
-                print("tracklog: error, the cron module is not loaded")
+                self.log.error("the modRana cron module is not available")
 
     def _saveIntervalChangedCB(self, key, oldInterval, newInterval):
         if self.updateLogTimerId:
@@ -349,9 +342,9 @@ class Tracklog(RanaModule):
             interval = int(newInterval) * 1000
             if cron:
                 cron.modifyTimeout(self.saveLogTimerId, interval)
-                print('tracklog: tracklog save interval changed to %s s' % newInterval)
+                self.log.info('tracklog save interval changed to %s s' % newInterval)
             else:
-                print("tracklog: error, the cron module is not loaded")
+                self.log.error("the modRana cron module is not available")
 
     def _stopTimers(self):
         """stop the update and save timers"""
@@ -361,9 +354,9 @@ class Tracklog(RanaModule):
             cron.removeTimeout(self.saveLogTimerId)
             self.saveLogTimerId = None
             self.updateLogTimerId = None
-            print("tracklog: track logging timers stopped")
+            self.log.info("track logging timers stopped")
         else:
-            print("tracklog: error, the cron module is not loaded")
+            self.log.error("the modRana cron module is not available")
 
     def stopLogging(self):
         """stop logging, export the log to GPX and delete the temporary
@@ -448,14 +441,6 @@ class Tracklog(RanaModule):
     #    last_y = y
     #print("bod")
 
-    #  def update(self):
-    #    # Run scheduledUpdate every second
-    #    t = time()
-    #    dt = t - self.updateTime
-    #    if(dt > self.get("logPeriod", 2)):
-    #      self.updateTime = t
-    #      self.scheduledUpdate()
-
     def initToolsMenu(self):
         """initialize the tools submenu"""
         menus = self.m.get('menu', None)
@@ -516,7 +501,7 @@ class Tracklog(RanaModule):
         if menuName == 'tracklog':
             # is the submenu initialized ?
             if self.toolsMenuDone == False:
-                print("tracklog: setting up tracklogTools menu")
+                self.log.debug("setting up tracklogTools menu")
                 self.initToolsMenu()
                 self.toolsMenuDone = True
 
@@ -601,7 +586,7 @@ class Tracklog(RanaModule):
             if menus:
                 menus.drawSixPlusOneMenu(cr, menuName, parentAction, fiveButtons, box)
             else:
-                print('tracklog: error, menus module is missing')
+                self.log.error('menus module is missing')
 
         else:
             return # we aren't the active menu so we dont do anything
@@ -650,8 +635,8 @@ class Tracklog(RanaModule):
 
                     # draw a track to current position (if known):
 
-                #      print(z, modulo)
-                #      print(counter, drawCount)
+                #      self.log.info(z, modulo)
+                #      self.log.info(counter, drawCount)
 
             cr.stroke()
             cr.fill()
@@ -673,10 +658,10 @@ class Tracklog(RanaModule):
             self.set('needRedraw', True)
 
         if primaryLogs:
-            print('tracklog: exporting %d unsaved primary log files to GPX' % len(primaryLogs))
+            self.log.info('exporting %d unsaved primary log files to GPX', len(primaryLogs))
             for logPath in primaryLogs:
                 # export any found files
-                print('tracklog: exporting %s to GPX' % logPath)
+                self.log.info('exporting %s to GPX', logPath)
                 try:
                     w1 = way.fromCSV(logPath, delimiter=",")
                     exportPath = "%s.gpx" % os.path.splitext(logPath)[0]
@@ -686,37 +671,27 @@ class Tracklog(RanaModule):
                     if os.path.exists(exportPath): # save to backup path
                         exportPath = "%s_1.gpx" % os.path.splitext(logPath)[0]
                     w1.saveToGPX(exportPath)
-                    print('tracklog: GPX export successful')
+                    self.log.info('GPX export successful')
                     # success, delete temporary files
 
                     # primary
                     os.remove(logPath)
-                    print('tracklog: temporary file %s deleted' % logPath)
+                    self.log.debug('primary temporary file %s deleted', logPath)
                     # secondary
                     secondaryPath = "%s.temporary_csv_2" % os.path.splitext(logPath)[0]
                     if os.path.exists(secondaryPath):
                         os.remove(secondaryPath)
-                        print('tracklog: temporary file %s deleted' % secondaryPath)
+                        self.log.debug('secondary temporary file %s deleted', secondaryPath)
 
                 except Exception:
-
-                    import sys
-
-                    e = sys.exc_info()[1]
-                    print('tracklog: exporting unsaved primary log file failed')
-                    print(e)
+                    self.log.exception('exporting unsaved primary log file failed')
                     failedPath = "%s_1.csv" % os.path.splitext(logPath)[0]
-                    print('tracklog: renaming to %s instead' % failedPath)
+                    self.log.info('renaming to %s instead', failedPath)
                     try:
                         shutil.move(logPath, failedPath)
-                        print("tracklog: renaming successful")
+                        self.log.info("renaming successful")
                     except Exception:
-                        import sys
-
-                        e = sys.exc_info()[1]
-                        print('tracklog: renaming %s to %s failed' % (logPath, failedPath))
-                        print(e)
-
+                        self.log.exception('renaming %s to %s failed', logPath, failedPath)
 
         # rescan for secondary logs
         # (there should be only secondary logs that
@@ -726,10 +701,10 @@ class Tracklog(RanaModule):
 
         secondaryLogs = glob.glob("%s/*.temporary_csv_2" % logFolder)
         if secondaryLogs:
-            print('tracklog: exporting %d unsaved secondary log files to GPX' % len(primaryLogs))
+            self.log.info('exporting %d unsaved secondary log files to GPX' % len(primaryLogs))
             for logPath in secondaryLogs:
                 # export any found files
-                print('tracklog: exporting %s to GPX' % logPath)
+                self.log.info('exporting %s to GPX' % logPath)
                 try:
                     w2 = way.fromCSV(logPath, delimiter=",")
                     exportPath = "%s.gpx" % os.path.splitext(logPath)[0]
@@ -739,31 +714,23 @@ class Tracklog(RanaModule):
                     if os.path.exists(exportPath): # save to backup path
                         exportPath = "%s_2.gpx" % os.path.splitext(logPath)[0]
                     w2.saveToGPX(exportPath)
-                    print('tracklog: GPX export successful')
+                    self.log.info('GPX export successful')
                     # success, delete temporary file
 
                     # secondary
                     # (primary is either not there or was already removed in primary pass)
                     os.remove(logPath)
-                    print('tracklog: temporary file %s deleted' % logPath)
+                    self.log.info('secondary temporary file %s deleted' % logPath)
 
                 except Exception:
-                    import sys
-
-                    e = sys.exc_info()[1]
-                    print('tracklog: exporting unsaved secondary log file failed')
-                    print(e)
+                    self.log.exception('exporting unsaved secondary log file failed')
                     failedPath = "%s_2.csv" % os.path.splitext(logPath)[0]
-                    print('tracklog: renaming to %s instead' % failedPath)
+                    self.log.info('renaming to %s instead', failedPath)
                     try:
                         shutil.move(logPath, failedPath)
-                        print("tracklog: renaming successful")
+                        self.log.info("renaming successful")
                     except Exception:
-                        import sys
-
-                        e = sys.exc_info()[1]
-                        print('tracklog: renaming %s to %s failed' % (logPath, failedPath))
-                        print(e)
+                        self.log.exception('renaming %s to %s failed', logPath, failedPath)
 
     def shutdown(self):
         # try to stop and save the log
